#[non_exhaustive]pub enum ClientErrorCategory {
Show 13 variants
InvalidInput,
AuthRequired,
AuthExpired,
ReloginRequired,
Network,
Timeout,
RateLimited,
ProtocolMismatch,
NotFound,
PermissionDenied,
Unsupported,
Conflict,
Internal,
}Expand description
Stable error categories exposed to client hosts.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidInput
Caller supplied invalid input.
AuthRequired
Authentication is missing.
AuthExpired
Authentication expired and must be refreshed.
ReloginRequired
The user must relogin interactively.
Network
Network connectivity failed.
Timeout
Operation timed out.
RateLimited
Remote server rate limited the operation.
ProtocolMismatch
Local and remote protocol versions are incompatible.
NotFound
The target entity was not found.
PermissionDenied
The account does not have permission for the operation.
Unsupported
The operation is unsupported by the current client or server.
Conflict
The operation conflicted with newer state.
Internal
An internal client error occurred.