#[non_exhaustive]pub enum ClientCommandError {
Closed,
ResponseDropped,
}Expand description
Errors returned by the async client handle before an operation reaches the backend.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Closed
The client runner has stopped accepting commands.
ResponseDropped
The client runner dropped a command response before completing it.