pub struct InlineClientBuilder { /* private fields */ }Expand description
Builder for an InlineClient runtime.
Implementations
Sourceimpl InlineClientBuilder
impl InlineClientBuilder
Sourcepub fn backend(self, backend: impl ClientBackend) -> Self
pub fn backend(self, backend: impl ClientBackend) -> Self
Sets the backend used by the runner.
Sets the shared backend used by the runner.
Sourcepub fn command_queue_capacity(self, capacity: usize) -> Self
pub fn command_queue_capacity(self, capacity: usize) -> Self
Sets the bounded command queue capacity.
Sourcepub fn max_concurrent_requests(self, maximum: usize) -> Self
pub fn max_concurrent_requests(self, maximum: usize) -> Self
Sets the maximum number of backend requests allowed in flight.
Sourcepub fn event_queue_capacity(self, capacity: usize) -> Self
pub fn event_queue_capacity(self, capacity: usize) -> Self
Sets the broadcast event queue capacity.
Sourcepub fn lossless_event_queue_capacity(self, capacity: usize) -> Self
pub fn lossless_event_queue_capacity(self, capacity: usize) -> Self
Sets the bounded queue capacity for the optional lossless event consumer.
Sourcepub fn reconnect_policy(self, policy: ReconnectPolicy) -> Self
pub fn reconnect_policy(self, policy: ReconnectPolicy) -> Self
Sets event-stream reconnect and rate-limit backoff policy.
Sourcepub fn initial_status(self, status: ClientStatus) -> Self
pub fn initial_status(self, status: ClientStatus) -> Self
Sets the initial client status.
Sourcepub fn build(self) -> InlineClientRuntime
pub fn build(self) -> InlineClientRuntime
Builds a client handle and runner pair.