Module sdk_backend

Module sdk_backend 

SDK-backed backend implementation. SDK-backed production backend.

This backend owns the configured inline-sdk clients, durable store, multiplexed realtime session, bucket sync, and transaction state behind the native client API.

Structs

SdkBackend
Production-facing backend composed from inline-sdk and a client store.
SdkBackendBuilder
Builder for SdkBackend.

Enums

SdkBackendBuildError
Error returned when building an SdkBackend.