pub struct ClientEventDelivery {
pub delivery_id: Option<u64>,
pub event: ClientEvent,
}Expand description
One client event prepared for delivery to the single lossless consumer.
Lossless events have a durable positive delivery_id. Best-effort events
are carried through the same ordered batch with no durable identifier.
Fields
delivery_id: Option<u64>Store-local identifier used to acknowledge a durable lossless event.
event: ClientEventCommitted client event.
Implementations
Sourceimpl ClientEventDelivery
impl ClientEventDelivery
Sourcepub fn ephemeral(event: ClientEvent) -> Self
pub fn ephemeral(event: ClientEvent) -> Self
Creates an event that does not require durable acknowledgement.