pub struct StoredTransaction {
pub identity: TransactionIdentity,
pub state: TransactionState,
pub chat_id: Option<InlineId>,
pub message_id: Option<InlineId>,
pub failure: Option<ClientFailure>,
pub created_at: i64,
pub updated_at: i64,
}Expand description
Stored durable transaction state.
Fields
identity: TransactionIdentityMutation identity and reconciliation IDs.
state: TransactionStateCurrent transaction state.
chat_id: Option<InlineId>Chat containing the transaction, when known.
message_id: Option<InlineId>Final message ID, when known.
failure: Option<ClientFailure>Redacted failure for failed transactions.
created_at: i64Unix timestamp in seconds when the transaction row was created.
updated_at: i64Unix timestamp in seconds when the transaction row was last updated.
Implementations
Sourceimpl StoredTransaction
impl StoredTransaction
Sourcepub fn new(identity: TransactionIdentity, state: TransactionState) -> Self
pub fn new(identity: TransactionIdentity, state: TransactionState) -> Self
Creates a stored transaction in the provided state.
Sourcepub fn with_chat_id(self, chat_id: InlineId) -> Self
pub fn with_chat_id(self, chat_id: InlineId) -> Self
Sets the chat ID.
Sourcepub fn with_message_id(self, message_id: InlineId) -> Self
pub fn with_message_id(self, message_id: InlineId) -> Self
Sets the final message ID.
Sourcepub fn with_failure(self, failure: ClientFailure) -> Self
pub fn with_failure(self, failure: ClientFailure) -> Self
Sets the redacted failure.
Sourcepub fn event(&self) -> TransactionEvent
pub fn event(&self) -> TransactionEvent
Converts to a client event payload.