pub struct SyncState {
pub last_sync_date: i64,
}Expand description
Durable global synchronization state.
last_sync_date is the newest server update date that the client has
coherently applied. It is used as the discovery cursor for
getUpdatesState after startup and reconnect.
Fields
last_sync_date: i64Latest coherently applied server update date, in Unix seconds.