ClientEvent

Enum ClientEvent 

#[non_exhaustive]
pub enum ClientEvent { StatusChanged { status: ClientStatus, failure: Option<ClientFailure>, }, TransactionChanged(TransactionEvent), ChatUpserted { chat_id: InlineId, }, UserUpserted { user_id: InlineId, }, MessageUpserted { chat_id: InlineId, message_id: InlineId, }, MessageStored { message: MessageRecord, }, MessageDeleted { chat_id: InlineId, message_id: InlineId, }, ReactionChanged { chat_id: InlineId, message_id: InlineId, user_id: InlineId, reaction: String, removed: bool, }, ReadStateChanged { chat_id: InlineId, }, Typing { chat_id: InlineId, user_id: InlineId, is_typing: bool, }, }
Committed client event for apps, bridges, agents, and hosts.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


StatusChanged

Connection/auth status changed.

Fields

status: ClientStatus

New client status.

failure: Option<ClientFailure>

Optional redacted failure details.



TransactionChanged(TransactionEvent)

A durable transaction changed state.



ChatUpserted

A chat was inserted or updated in the local store.

Fields

chat_id: InlineId

Inline chat ID.



UserUpserted

A user was inserted or updated in the local store.

Fields

user_id: InlineId

Inline user ID.



MessageUpserted

A message was inserted or updated in the local store.

Fields

chat_id: InlineId

Inline chat ID.

message_id: InlineId

Inline message ID.



MessageStored

A message was inserted or updated and the committed record is available.

Fields

message: MessageRecord

Committed message record.



MessageDeleted

A message was deleted or unsent.

Fields

chat_id: InlineId

Inline chat ID.

message_id: InlineId

Inline message ID.



ReactionChanged

Reactions for a message changed.

Fields

chat_id: InlineId

Inline chat ID.

message_id: InlineId

Inline message ID.

user_id: InlineId

Inline user ID that changed the reaction.

reaction: String

Reaction emoji.

removed: bool

Whether the reaction was removed.



ReadStateChanged

Read state changed for a chat.

Fields

chat_id: InlineId

Inline chat ID.



Typing

Typing state changed.

Fields

chat_id: InlineId

Inline chat ID.

user_id: InlineId

Inline user ID.

is_typing: bool

Whether the user is typing.

Implementations

Source

impl ClientEvent

pub const fn reliability(&self) -> EventReliability

Returns the event delivery reliability class.