#[non_exhaustive]pub enum ClientEvent {
StatusChanged {
status: ClientStatus,
failure: Option<ClientFailure>,
},
TransactionChanged(TransactionEvent),
ChatUpserted {
chat_id: InlineId,
},
UserUpserted {
user_id: InlineId,
},
MessageUpserted {
chat_id: InlineId,
message_id: InlineId,
},
MessageStored {
message: MessageRecord,
},
MessageDeleted {
chat_id: InlineId,
message_id: InlineId,
},
ReactionChanged {
chat_id: InlineId,
message_id: InlineId,
user_id: InlineId,
reaction: String,
removed: bool,
},
ReadStateChanged {
chat_id: InlineId,
},
Typing {
chat_id: InlineId,
user_id: InlineId,
is_typing: bool,
},
}Expand description
Committed client event for apps, bridges, agents, and hosts.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
StatusChanged
Connection/auth status changed.
Fields

status: ClientStatusNew client status.

failure: Option<ClientFailure>Optional redacted failure details.
TransactionChanged(TransactionEvent)
A durable transaction changed state.
ChatUpserted
A chat was inserted or updated in the local store.
UserUpserted
A user was inserted or updated in the local store.
MessageUpserted
A message was inserted or updated in the local store.
MessageStored
A message was inserted or updated and the committed record is available.
Fields

message: MessageRecordCommitted message record.
MessageDeleted
A message was deleted or unsent.
ReactionChanged
Reactions for a message changed.
Fields
ReadStateChanged
Read state changed for a chat.
Typing
Typing state changed.
Implementations
Sourceimpl ClientEvent
impl ClientEvent
Sourcepub const fn reliability(&self) -> EventReliability
pub const fn reliability(&self) -> EventReliability
Returns the event delivery reliability class.